const canvas = document.getElementById('network-canvas');
const ctx = canvas.getContext('2d');

const nodes = [
  { id: 'Indiranagar', x: 100, y: 50 },
  { id: 'Koramangala', x: 250, y: 100 },
  { id: 'MG Road', x: 400, y: 50 },
  { id: 'Whitefield', x: 250, y: 250 },
  { id: 'Banashankari', x: 600, y: 150 },
  { id: 'Malleswaram', x: 750, y: 200 },
  { id: 'Jayanagar', x: 600, y: 250 },
  { id: 'Basavanagudi', x: 450, y: 300 },
  { id: 'Electronic City', x: 100, y: 250 },
  { id: 'Hebbal', x: 100, y: 100 },
];

const links = [
  { source: 'Indiranagar', target: 'Koramangala' },
  { source: 'Indiranagar', target: 'MG Road' },
  { source: 'Indiranagar', target: 'Electronic City' },
  { source: 'Koramangala', target: 'Whitefield' },
  { source: 'MG Road', target: 'Banashankari' },
  { source: 'Whitefield', target: 'Banashankari' },
  { source: 'Banashankari', target: 'Malleswaram' },
  { source: 'Banashankari', target: 'Jayanagar' },
  { source: 'Malleswaram', target: 'Basavanagudi' },
  { source: 'Jayanagar', target: 'Koramangala' },
  { source: 'Jayanagar', target: 'MG Road' },
  { source: 'Basavanagudi', target: 'Whitefield' },
  { source: 'Basavanagudi', target: 'Banashankari' },
  { source: 'Hebbal', target: 'MG Road' },
  { source: 'Hebbal', target: 'Whitefield' },
  { source: 'Hebbal', target: 'Basavanagudi' },
];

function drawNodes() {
  nodes.forEach((node) => {
    const sides = 6; // Number of sides for polygon
    const radius = 30; // Radius of polygon, increased from 20 to 30

    ctx.beginPath();
    ctx.moveTo(
      node.x + radius * Math.cos(0),
      node.y + radius * Math.sin(0),
    );

    for (let i = 1; i <= sides; i++) {
      ctx.lineTo(
        node.x +
          radius * Math.cos((i * 2 * Math.PI) / sides),
        node.y +
          radius * Math.sin((i * 2 * Math.PI) / sides),
      );
    }

    ctx.closePath();
    ctx.fillStyle = '#FF6347'; // Tomato
    ctx.fill();

    // Node label
    ctx.fillStyle = 'black'; // Change text color to black
    ctx.font = '14px Arial';
    ctx.textAlign = 'center';
    ctx.textBaseline = 'middle';
    ctx.fillText(node.id, node.x, node.y);
  });
}

function drawLinks() {
  links.forEach((link) => {
    const sourceNode = nodes.find(
      (node) => node.id === link.source,
    );
    const targetNode = nodes.find(
      (node) => node.id === link.target,
    );

    ctx.beginPath();
    ctx.moveTo(sourceNode.x, sourceNode.y);
    ctx.lineTo(targetNode.x, targetNode.y);
    ctx.strokeStyle = 'black'; // Change link color to black
    ctx.setLineDash([5, 5]); // Set line style to dashed with 5 pixels on and off
    ctx.lineWidth = 2; // Keep line width as 2
    ctx.stroke();
  });
}

function drawGraph() {
  drawLinks();
  drawNodes();
}

function adjustCanvasSize() {
  let maxX = 0;
  let maxY = 0;

  nodes.forEach((node) => {
    if (node.x > maxX) maxX = node.x;
    if (node.y > maxY) maxY = node.y;
  });

  canvas.width = maxX + 50;
  canvas.height = maxY + 50;
}

adjustCanvasSize();
drawGraph();
